# Install and load necessary packages
 install.packages("maps")
 install.packages("ggplot2")
 install.packages("ggrepel")
options(repos = c(CRAN = "https://cloud.r-project.org"))
library(haven)
library(maps)
library(ggplot2)
library(dplyr)
library(readr)
library(ggrepel)

# working directory
setwd("C:/Users/wb558768/Documents/GitHub/disruptive/Replication package-Disruptive")


###################################################################################################################
# load data
geocoded_firm <- read_dta("working/Geocoded_roster_for_geo_vf_citycountry.dta")

# count number of firms
n_firm_africa <- geocoded_firm %>% 
  filter(region == 4) %>% 
  group_by(uniq_address_name_vf) %>% 
  summarise(n_firm = n(), .groups = 'drop')

# coordinate
geocode_africa <- distinct(geocoded_firm, uniq_address_name_vf, .keep_all = TRUE)
geocode_africa <- geocode_africa %>% 
  filter(region == 4) %>% 
  select(uniq_address_name_vf,Latitude,Longitude)

# merge number of firm with coordinate
geocoded_firm_africa <- merge(n_firm_africa, 
                              geocode_africa, 
                              by = "uniq_address_name_vf", 
                              all = TRUE)

write_csv(geocoded_firm_africa,"working/nfirm_geocoded.csv")

# Get world map data from the 'maps' package
world_map <- map_data("world")

# Filter the map data to include only African countries
africa_map <- subset(world_map, region %in% c("Algeria", "Angola", "Benin", "Botswana", 
                                              "Burkina Faso", "Burundi", "Cameroon", 
                                              "Cape Verde", "Central African Republic", 
                                              "Chad", "Republic of Congo", "Comoros", 
                                              "Democratic Republic of the Congo", 
                                              "Djibouti", "Egypt", "Equatorial Guinea", 
                                              "Eritrea", "Eswatini", "Ethiopia", "Gabon", 
                                              "Gambia", "Ghana", "Guinea", "Guinea-Bissau", 
                                              "Ivory Coast", "Kenya", "Lesotho", "Liberia", 
                                              "Libya", "Madagascar", "Malawi", "Mali", 
                                              "Mauritania", "Mauritius", "Morocco", 
                                              "Mozambique", "Namibia", "Niger", 
                                              "Nigeria", "Republic of the Congo", 
                                              "Rwanda", "Sao Tome and Principe", 
                                              "Senegal", "Seychelles", "Sierra Leone", 
                                              "Somalia", "South Africa", "South Sudan", 
                                              "Sudan", "Tanzania", "Togo", "Tunisia", 
                                              "Uganda", "Zambia", "Zimbabwe"))



map_africa <- ggplot() +
  geom_polygon(data = africa_map, aes(x = long, y = lat, group = group), fill = "white", color = "grey") +
  geom_point(data = geocoded_firm_africa %>% filter(n_firm < 100), aes(x = Longitude, y = Latitude, size = n_firm, color = "Firm Count < 100"), show.legend = TRUE) +
  geom_point(data = geocoded_firm_africa %>% filter(n_firm >= 100), aes(x = Longitude, y = Latitude, size = n_firm, color = "Firm Count >= 100"), show.legend = TRUE) +
  geom_label_repel(data = geocoded_firm_africa %>% filter(n_firm >= 100), aes(x = Longitude, y = Latitude, label = uniq_address_name_vf), size = 2, fill = NA, color = "black", fontface = "bold", box.padding = 0.3, max.overlaps = Inf) + # Using geom_label_repel

   scale_color_manual(values = c("Firm Count < 100" = "darkseagreen2", "Firm Count >= 100" = "firebrick1")) +
  scale_size(range = c(1, 10)) +
  labs(title = "", color = "", size = "Firm Count") +
  theme(panel.background = element_rect(fill = "white"),
        axis.text = element_blank(),
        axis.title = element_blank(),
        legend.position = c(.35,0.05),
        legend.justification = c(1, 0),
        legend.direction = "vertical",
        legend.box.margin = margin(t = 10, r = 10, b = 90, l = 10),
        legend.title = element_text(size = 10),
        legend.text = element_text(size = 7),
        axis.line = element_blank(),
        axis.ticks = element_blank(),
        legend.margin = margin(0, 0, 0, 0),
        plot.margin = margin(0, 0, 0, 0))

ggsave("figures/Figure1_nfirm_geocoded_v2.png", plot = map_africa, width = 7, height = 7, units = "in")
ggsave("figures/Figure1_nfirm_geocoded_v2.eps", plot = map_africa, width = 7, height = 7, units = "in")
