clear 
set more off

/*
This dofiles pulls raw dta from crunchbase to produce a roster of firms 
Original data is not included due to confidentiality restrictions, but this script 
describes the actions taken to prepare the roster.dta
*/


** DATA
local vars headquarterslocation organizationname industries description fulldescription foundeddate exitdate numberoffundingrounds v58 cbrankcompany lastfundingamountcurrencyinusd numberofemployees similarcompanies organizationnameurl builtwithactivetechcount v58 estimatedrevenuerange lastfundingamountcurrency closeddate totalfundingamountcurrencyinusd ipqwerytotalpatents

local sectors ecommerce fintech it

foreach sector in `sectors' {
	local lista : dir "$data/crunchbase" files "`sector'*.csv"
	di `"`lista'"'

	cap erase "$working/`sector'".dta
	foreach file of local lista {
		qui import delimited "$data/crunchbase/`file'", clear
		keep `vars' founders
		gen file = "`file'"
		qui tostring lastfundingamountcurrency, replace force
		qui destring ipqwerytotalpatents, replace force
		qui destring similarcompanies, ignore(",") force replace
		qui tostring closeddate, replace force
		di "`file'"
		cap append using "$working/`sector'"
		cou
		save "$working/`sector'", replace
	}
}

use "$working/ecommerce"
append using "$working/fintech"
append using "$working/it"

gen sector = .
replace sector = 1 if regexm(file,"ecommerce_")
replace sector = 2 if regexm(file,"fintech_")
replace sector = 3 if regexm(file,"it_")
label define sector 1 "E-Commerce" 2 "Fintech" 3 "IT"
label values sector sector

gen region = .
replace region = 1 if regexm(file,"london")
replace region = 1 if regexm(file,"tokyo")
replace region = 1 if regexm(file,"seattle")
replace region = 1 if regexm(file,"paloalto")

replace region = 2 if regexm(file,"top1000")
replace region = 3 if regexm(file,"top1000rev")

replace region = 4 if regexm(file,"africa")
replace region = 4 if regexm(file,"egypt")
replace region = 4 if regexm(file,"keghaug")
replace region = 4 if regexm(file,"nigeria")
replace region = 4 if regexm(file,"zaf")

replace region = 5 if regexm(file,"southamerica")
replace region = 5 if regexm(file,"brazil")
replace region = 5 if regexm(file,"mexico")
replace region = 5 if regexm(file,"argentina")
replace region = 5 if regexm(file,"chile")
replace region = 5 if regexm(file,"colombia")
replace region = 5 if regexm(file,"boecpapeur")

label define region 1 "Fontier" 2 "Top1000" 3 "Top1000Rev" 4 "Africa" 5 "LAC"
label values region region

rename organizationnameurl orgname
replace orgname = subinstr(orgname,"https://www.crunchbase.com/organization/","",.)

duplicates drop orgname sector region, force

gen geo = headquarterslocation 
split geo, parse(,)
rename geo3 country
replace country = trim(country)
drop if country == "a"
replace country = "London" if regexm(file,"london")
replace country = "Tokyo" if regexm(file,"tokyo")
replace country = "Seattle" if regexm(file,"seattle")
replace country = "Palo Alto" if regexm(file,"paloalto")
replace country = "Top1000" if regexm(file,"top1000")
replace country = "Top1000R" if regexm(file,"top1000rev")
drop geo* 

drop if country == "United States"
egen country_id = group(country)

gen year_start = real(substr(foundeddate,1,4))
gen age = 2022 - year_start
recode age (-1 = 0)
drop foundeddate 

destring cbrankcompany, ignore(",") gen(rank_cb)
drop cbrankcompany

destring lastfundingamountcurrencyinusd, replace force
recode lastfundingamountcurrencyinusd (. = 0), gen(funding_last)
drop lastfundingamountcurrencyinusd

cap destring totalfundingamountcurrencyinusd, replace force
recode totalfundingamountcurrencyinusd (. = 0), gen(funding_total)
drop totalfundingamountcurrencyinusd

recode ipqwerytotalpatents (. = 0), gen(patents)
rename lastfundingamountcurrency funding_currency
recode v58 (. = 0)

gen labor = .
replace labor = 1 if numberofemployees == "10-Jan"
replace labor = 1 if numberofemployees == "1-10"
replace labor = 2 if numberofemployees == "11-50"
replace labor = 2 if numberofemployees == "Nov-50"
replace labor = 3 if numberofemployees == "51-100"
replace labor = 4 if numberofemployees == "101-250"
replace labor = 5 if numberofemployees == "251-500"
replace labor = 6 if numberofemployees == "501-1000"
replace labor = 7 if numberofemployees == "1001-5000"
replace labor = 8 if numberofemployees == "5001-10000"
replace labor = 9 if numberofemployees == "10001+"
drop numberofemployees

gen revenue = .
replace revenue = 1 if estimatedrevenuerange == "Less than $1M"
replace revenue = 2 if estimatedrevenuerange == "$1M to $10M"
replace revenue = 3 if estimatedrevenuerange == "$10M to $50M"
replace revenue = 4 if estimatedrevenuerange == "$50M to $100M"
replace revenue = 5 if estimatedrevenuerange == "$100M to $500M"
replace revenue = 6 if estimatedrevenuerange == "$500M to $1B"
replace revenue = 7 if estimatedrevenuerange == "$1B to $10B"
replace revenue = 8 if estimatedrevenuerange == "$10B+"

destring similarcompanies, ignore(",") replace
recode similarcompanies (. = 0), gen(similar)
drop similarcompanies

destring builtwithactivetechcount, replace force
rename builtwithactivetechcount btechnologies

duplicates tag orgname country, gen(overlap)

replace industries = trim(lower(industries))
replace description = trim(lower(description))
replace fulldescription = trim(lower(fulldescription))

foreach var in industries description fulldescription {
	replace `var' = subinstr(`var',"-"," ",.)
	replace `var' = subinstr(`var',"wi fi","wifi",.)
	replace `var' = subinstr(`var',"e commerce","e-commerce",.)	
}

gen M = _n
order M orgname

gen firm_id = string(M)

save "$working/roster", replace

erase "$working/ecommerce.dta"
erase "$working/fintech.dta"
erase "$working/it.dta"