clear 
set more off
set scheme s1color

/*
This dofile caculates the share of disruptive firms by industry in the frontier
*/

** PATHS (Only if it is run separately from the Main do file)
*global working ../working
*global figures ../figures
*globaltables ../tables

** DATA
use "$working/roster", clear
merge 1:1 firm_id using "$working/roster_technology_list_wide"
drop _merge
recode tech_* (. = 0)

replace country = "United States" if country == "Palo Alto" | country == "Seattle"
replace country = "United Kingdom" if country == "London"
replace country = "Japan" if country == "Tokyo"

*keep if year_start <= 2010

egen technologies = rowtotal(tech_*)
gen disruptive = technologies > 0
gen technologies_nm = technologies - (tech_6)
gen disruptive_nm = technologies_nm > 0

split industries, gen(ind_) parse(",")
forvalues x = 1/50 {
	cap replace ind_`x' = trim(ind_`x')
}

keep if inlist(region,1) // keep only the frontier
keep ind_* disruptive* 

gen n = _n

reshape long ind_, i(n disruptive disruptive_nm) j(k)

drop if ind_ == ""

collapse (mean) disruptive*, by(ind_)

rename disruptive shareD
rename disruptive_nm shareDnm

save "$working/shareF", replace