clear 
set more off
set scheme s1color

** PATHS
/*
local working ../working
local figures ../figures
local tables ../tables
*/
** DATA
use "$working/roster", clear

split industries, gen(ind_) parse(",")

keep firm_id sector region ind_*
reshape long ind_, i(firm_id sector region) j(j)
drop if ind_ == ""

replace ind_ = trim(itrim(ind_))

gen n = 1
collapse (sum) n, by(region sector ind_)

egen N = sum(n), by(region sector)

gen share = n / N

keep if inlist(region,1,4,5)
gsort region sector -share

by region sector: gen rank = _n

replace ind_ = "ict" if regexm(ind_,"information and communications technology")

replace ind_ = "REST" if rank > 20

collapse (sum) n, by(region sector ind_)

egen N = sum(n), by(region sector)

gen share = n / N

gsort region sector -share

reshape wide share n N, i(sector ind_) j(region)
drop if ind_ == "REST"

gen lshare1 = ln(share1)
gen lshare4 = ln(share4)
gen lshare5 = ln(share5)

recode lshare* (. = -6)
recode share* (. = 0)

gen gap = share4 - share1
gsort sector -gap
gen rank = _n

labmask rank, val(ind_)

sum rank if sector == 1
local min = r(min)
local max = r(max)
two (bar gap rank if sector == 1), xlabel(`min'(1)`max',valuelabel labsize(small) angle(90)) ytitle(Difference Africa - Frontier, size(small)) xtitle(,size(zero)) 
graph export "$figures/Figure_B5_textgap_ecommerce.png", replace


sum rank if sector == 2
local min = r(min)
local max = r(max)
two (bar gap rank if sector == 2), xlabel(`min'(1)`max',valuelabel labsize(small) angle(90))ytitle(Difference Africa - Frontier, size(small)) xtitle(,size(zero)) 
graph export "$figures/Figure_B6_textgap_fintech.png", replace

sum rank if sector == 3
local min = r(min)
local max = r(max)
two (bar gap rank if sector == 3), xlabel(`min'(1)`max',valuelabel labsize(small) angle(90))ytitle(Difference Africa - Frontier, size(small)) xtitle(,size(zero)) 
graph export "$figures/Figure_B7_textgap_it.png", replace
