clear
set more off
set scheme s1color

** PATHS
*global working ../working
*global figures ../figures
*global  tables ../tables

** DATA
use "$working/roster", clear
merge 1:1 firm_id using "$working/roster_technology_list_wide"
drop _merge
recode tech_* (. = 0)

replace country = "United States" if country == "Palo Alto" | country == "Seattle"
replace country = "United Kingdom" if country == "London"
replace country = "Japan" if country == "Tokyo"

qui include "$dofiles/01_dataprep/iso_code.do"

egen technologies = rowtotal(tech_*)
gen disruptive = technologies > 0
gen technologies_nm = technologies - (tech_7 + tech_14)
gen disruptive_nm = technologies_nm > 0

compress

replace age = age - 1
recode age (-1 = 0)

gen lage = ln(age + sqrt(age^2 + 1))
gen lsimilar = ln(similar + sqrt(similar^2 + 1))
gen lfundingl = ln(funding_last + sqrt(funding_last^2 + 1))
gen lfundingt = ln(funding_total + sqrt(funding_total^2 + 1))
gen lequity = ln(v58 + sqrt(v58^2 + 1))

recode technologies (2/99 = 2), gen(technologies_censored)
gen technologies_dummy = technologies > 0

recode technologies_nm (2/99 = 2), gen(technologies_nm_censored)
gen technologies_nm_dummy = technologies_nm > 0

gen tech_rate = technologies / btechnologies

sort orgname country sector
by orgname country: gen unique = _n

gen closed_year = real(substr(closeddate,1,4))

keep if closed_year == .

gen dft = funding_total > 0
gen dfl = funding_last > 0

***********************************************************************************************************************************************
* TABLES *
***********************************************************************************************************************************************
*********************************** table 1: funding_extensive.tex
* input: _funding_extensive.tex
local controls lsimilar lage overlap i.labor 

areg dft i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1, abs(country) vce(cluster country)
est store dft

areg dfl i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1, abs(country) vce(cluster country)
est store dfl

rename disruptive _dd
rename disruptive_nm disruptive
areg dft i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1, abs(country) vce(cluster country)
est store dftnm

areg dfl i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1, abs(country) vce(cluster country)
est store dflnm

rename disruptive disruptive_nm
rename _dd disruptive

noisily estout dft dfl dftnm dflnm using "$tables/Table1_funding_extensive.tex", style(tex) c(b(fmt(3) star) se(par fmt(3))) ///
	label collabels(, none) eqlabels(none) mlabels(, none) varlabel(_cons "constant" 1.disruptive "Disruptive" 1.disruptive#4.region "Disruptive $\times$ Africa"  1.disruptive#5.region "Disruptive $\times$ LAC") starlevel(* .1 ** .05 *** .01) ///
	keep(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	order(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	stats(r2 N N_clust, fmt(%9.3f %9.0g) labels(`"$ R ^{2}$"' "Observations" "Countries")) replace 

	
*********************************** table 2: funding_extensiveIHS.tex
* inputs: _funding_extensiveIHS.tex, _funding_extensiveIHS10.tex, and _funding_extensiveIHS11.tex
* table A2: funding_extensiveIHS.tex; with inputs: _funding_extensiveIHS.tex, _funding_extensiveIHS5.tex, and _funding_extensiveIHS6.tex

**** extensive IHS
local controls lsimilar lage overlap i.labor 

areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1, abs(country) vce(cluster country)
est store dft

areg lfundingl i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1, abs(country) vce(cluster country)
est store dfl

rename disruptive _dd
rename disruptive_nm disruptive
areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1, abs(country) vce(cluster country)
est store dftnm

areg lfundingl i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1, abs(country) vce(cluster country)
est store dflnm

rename disruptive disruptive_nm
rename _dd disruptive

noisily estout dft dfl dftnm dflnm using "$tables/Table2a_funding_extensiveIHS.tex", style(tex) c(b(fmt(3) star) se(par fmt(3))) ///
	label collabels(, none) eqlabels(none) mlabels(, none) varlabel(_cons "constant" 1.disruptive "Disruptive" 1.disruptive#4.region "Disruptive $\times$ Africa"  1.disruptive#5.region "Disruptive $\times$ LAC") starlevel(* .1 ** .05 *** .01) ///
	keep(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	order(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	stats(r2 N N_clust, fmt(%9.3f %9.0g) labels(`"$ R ^{2}$"' "Observations" "Countries")) replace 	
noisily estout dft dfl dftnm dflnm using "$tables/TableA2a_funding_extensiveIHS.tex", style(tex) c(b(fmt(3) star) se(par fmt(3))) ///
	label collabels(, none) eqlabels(none) mlabels(, none) varlabel(_cons "constant" 1.disruptive "Disruptive" 1.disruptive#4.region "Disruptive $\times$ Africa"  1.disruptive#5.region "Disruptive $\times$ LAC") starlevel(* .1 ** .05 *** .01) ///
	keep(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	order(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	stats(r2 N N_clust, fmt(%9.3f %9.0g) labels(`"$ R ^{2}$"' "Observations" "Countries")) replace 	
	
	
**** extensive IHS - startups (10)
areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age <= 10, abs(country) vce(cluster country)
est store dft

areg lfundingl i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age <= 10, abs(country) vce(cluster country)
est store dfl

rename disruptive _dd
rename disruptive_nm disruptive
areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age <= 10, abs(country) vce(cluster country)
est store dftnm

areg lfundingl i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age <= 10, abs(country) vce(cluster country)
est store dflnm

rename disruptive disruptive_nm
rename _dd disruptive

noisily estout dft dfl dftnm dflnm using "$tables/Table2b_funding_extensiveIHS10.tex", style(tex) c(b(fmt(3) star) se(par fmt(3))) ///
	label collabels(, none) eqlabels(none) mlabels(, none) varlabel(_cons "constant" 1.disruptive "Disruptive" 1.disruptive#4.region "Disruptive $\times$ Africa"  1.disruptive#5.region "Disruptive $\times$ LAC") starlevel(* .1 ** .05 *** .01) ///
	keep(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	order(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	stats(r2 N N_clust, fmt(%9.3f %9.0g) labels(`"$ R ^{2}$"' "Observations" "Countries")) replace 

**** extensive IHS - startups (5)
areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age <= 5, abs(country) vce(cluster country)
est store dft

areg lfundingl i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age <= 5, abs(country) vce(cluster country)
est store dfl

rename disruptive _dd
rename disruptive_nm disruptive
areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age <= 5, abs(country) vce(cluster country)
est store dftnm

areg lfundingl i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age <= 5, abs(country) vce(cluster country)
est store dflnm

rename disruptive disruptive_nm
rename _dd disruptive

noisily estout dft dfl dftnm dflnm using "$tables/TableA2b_funding_extensiveIHS5.tex", style(tex) c(b(fmt(3) star) se(par fmt(3))) ///
	label collabels(, none) eqlabels(none) mlabels(, none) varlabel(_cons "constant" 1.disruptive "Disruptive" 1.disruptive#4.region "Disruptive $\times$ Africa"  1.disruptive#5.region "Disruptive $\times$ LAC") starlevel(* .1 ** .05 *** .01) ///
	keep(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	order(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	stats(r2 N N_clust, fmt(%9.3f %9.0g) labels(`"$ R ^{2}$"' "Observations" "Countries")) replace 
	
**** extensive IHS - older (11+)
areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age > 10, abs(country) vce(cluster country)
est store dft

areg lfundingl i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age > 10, abs(country) vce(cluster country)
est store dfl

rename disruptive _dd
rename disruptive_nm disruptive
areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age > 10, abs(country) vce(cluster country)
est store dftnm

areg lfundingl i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age > 10, abs(country) vce(cluster country)
est store dflnm

rename disruptive disruptive_nm
rename _dd disruptive

noisily estout dft dfl dftnm dflnm using "$tables/Table2c_funding_extensiveIHS11.tex", style(tex) c(b(fmt(3) star) se(par fmt(3))) ///
	label collabels(, none) eqlabels(none) mlabels(, none) varlabel(_cons "constant" 1.disruptive "Disruptive" 1.disruptive#4.region "Disruptive $\times$ Africa"  1.disruptive#5.region "Disruptive $\times$ LAC") starlevel(* .1 ** .05 *** .01) ///
	keep(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	order(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	stats(r2 N N_clust, fmt(%9.3f %9.0g) labels(`"$ R ^{2}$"' "Observations" "Countries")) replace 

**** extensive IHS - older (6+)
areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age > 5, abs(country) vce(cluster country)
est store dft

areg lfundingl i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age > 5, abs(country) vce(cluster country)
est store dfl

rename disruptive _dd
rename disruptive_nm disruptive
areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age > 5, abs(country) vce(cluster country)
est store dftnm

areg lfundingl i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age > 5, abs(country) vce(cluster country)
est store dflnm

rename disruptive disruptive_nm
rename _dd disruptive

noisily estout dft dfl dftnm dflnm using "$tables/TableA2c_funding_extensiveIHS6.tex", style(tex) c(b(fmt(3) star) se(par fmt(3))) ///
	label collabels(, none) eqlabels(none) mlabels(, none) varlabel(_cons "constant" 1.disruptive "Disruptive" 1.disruptive#4.region "Disruptive $\times$ Africa"  1.disruptive#5.region "Disruptive $\times$ LAC") starlevel(* .1 ** .05 *** .01) ///
	keep(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	order(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	stats(r2 N N_clust, fmt(%9.3f %9.0g) labels(`"$ R ^{2}$"' "Observations" "Countries")) replace 

	
*********************************** table 3: funding_intensiveIHS.tex
* inputs: _funding_intensiveIHS.tex, _funding_intensiveIHS10.tex, and _funding_intensiveIHS11.tex
* table A3: funding_intensiveIHS.tex; with inputs _funding_intensiveIHS.tex, _funding_intensiveIHS5.tex, and _funding_intensiveIHS6.tex
**** intensive IHS
local controls lsimilar lage overlap i.labor 

areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & dft == 1, abs(country) vce(cluster country)
est store dft

areg lfundingl i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & dfl == 1, abs(country) vce(cluster country)
est store dfl

rename disruptive _dd
rename disruptive_nm disruptive
areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & dft == 1, abs(country) vce(cluster country)
est store dftnm

areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & dfl == 1, abs(country) vce(cluster country)
est store dflnm

rename disruptive disruptive_nm
rename _dd disruptive

noisily estout dft dfl dftnm dflnm using "$tables/Table3a_funding_intensiveIHS.tex", style(tex) c(b(fmt(3) star) se(par fmt(3))) ///
	label collabels(, none) eqlabels(none) mlabels(, none) varlabel(_cons "constant" 1.disruptive "Disruptive" 1.disruptive#4.region "Disruptive $\times$ Africa"  1.disruptive#5.region "Disruptive $\times$ LAC") starlevel(* .1 ** .05 *** .01) ///
	keep(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	order(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	stats(r2 N N_clust, fmt(%9.3f %9.0g) labels(`"$ R ^{2}$"' "Observations" "Countries")) replace 
noisily estout dft dfl dftnm dflnm using "$tables/TableA3a_funding_intensiveIHS.tex", style(tex) c(b(fmt(3) star) se(par fmt(3))) ///
	label collabels(, none) eqlabels(none) mlabels(, none) varlabel(_cons "constant" 1.disruptive "Disruptive" 1.disruptive#4.region "Disruptive $\times$ Africa"  1.disruptive#5.region "Disruptive $\times$ LAC") starlevel(* .1 ** .05 *** .01) ///
	keep(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	order(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	stats(r2 N N_clust, fmt(%9.3f %9.0g) labels(`"$ R ^{2}$"' "Observations" "Countries")) replace 

**** intensive IHS - startups (10)
areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age <= 10 & dft == 1, abs(country) vce(cluster country)
est store dft

areg lfundingl i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age <= 10 & dfl == 1, abs(country) vce(cluster country)
est store dfl

rename disruptive _dd
rename disruptive_nm disruptive
areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age <= 10 & dft == 1, abs(country) vce(cluster country)
est store dftnm

areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age <= 10 & dfl == 1, abs(country) vce(cluster country)
est store dflnm

rename disruptive disruptive_nm
rename _dd disruptive

noisily estout dft dfl dftnm dflnm using "$tables/Table3b_funding_intensiveIHS10.tex", style(tex) c(b(fmt(3) star) se(par fmt(3))) ///
	label collabels(, none) eqlabels(none) mlabels(, none) varlabel(_cons "constant" 1.disruptive "Disruptive" 1.disruptive#4.region "Disruptive $\times$ Africa"  1.disruptive#5.region "Disruptive $\times$ LAC") starlevel(* .1 ** .05 *** .01) ///
	keep(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	order(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	stats(r2 N N_clust, fmt(%9.3f %9.0g) labels(`"$ R ^{2}$"' "Observations" "Countries")) replace 

**** intensive IHS - startups (5)
areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age <= 5 & dft == 1, abs(country) vce(cluster country)
est store dft

areg lfundingl i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age <= 5 & dfl == 1, abs(country) vce(cluster country)
est store dfl

rename disruptive _dd
rename disruptive_nm disruptive
areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age <= 5 & dft == 1, abs(country) vce(cluster country)
est store dftnm

areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age <= 5 & dfl == 1, abs(country) vce(cluster country)
est store dflnm

rename disruptive disruptive_nm
rename _dd disruptive

noisily estout dft dfl dftnm dflnm using "$tables/TableA3b_funding_intensiveIHS5.tex", style(tex) c(b(fmt(3) star) se(par fmt(3))) ///
	label collabels(, none) eqlabels(none) mlabels(, none) varlabel(_cons "constant" 1.disruptive "Disruptive" 1.disruptive#4.region "Disruptive $\times$ Africa"  1.disruptive#5.region "Disruptive $\times$ LAC") starlevel(* .1 ** .05 *** .01) ///
	keep(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	order(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	stats(r2 N N_clust, fmt(%9.3f %9.0g) labels(`"$ R ^{2}$"' "Observations" "Countries")) replace 

**** intensive IHS - older (11)
areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age > 10 & dft == 1, abs(country) vce(cluster country)
est store dft

areg lfundingl i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age > 10 & dfl == 1, abs(country) vce(cluster country)
est store dfl

rename disruptive _dd
rename disruptive_nm disruptive
areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age > 10 & dft == 1, abs(country) vce(cluster country)
est store dftnm

areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age > 10 & dfl == 1, abs(country) vce(cluster country)
est store dflnm

rename disruptive disruptive_nm
rename _dd disruptive

noisily estout dft dfl dftnm dflnm using "$tables/Table3c_funding_intensiveIHS11.tex", style(tex) c(b(fmt(3) star) se(par fmt(3))) ///
	label collabels(, none) eqlabels(none) mlabels(, none) varlabel(_cons "constant" 1.disruptive "Disruptive" 1.disruptive#4.region "Disruptive $\times$ Africa"  1.disruptive#5.region "Disruptive $\times$ LAC") starlevel(* .1 ** .05 *** .01) ///
	keep(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	order(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	stats(r2 N N_clust, fmt(%9.3f %9.0g) labels(`"$ R ^{2}$"' "Observations" "Countries")) replace 

**** intensive IHS - older (6)
areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age > 5 & dft == 1, abs(country) vce(cluster country)
est store dft

areg lfundingl i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age > 5 & dfl == 1, abs(country) vce(cluster country)
est store dfl

rename disruptive _dd
rename disruptive_nm disruptive
areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age > 5 & dft == 1, abs(country) vce(cluster country)
est store dftnm

areg lfundingt i.disruptive##i.region `controls' if inlist(region,1,4,5) & unique == 1 & age > 5 & dfl == 1, abs(country) vce(cluster country)
est store dflnm

rename disruptive disruptive_nm
rename _dd disruptive

noisily estout dft dfl dftnm dflnm using "$tables/TableA3c_funding_intensiveIHS6.tex", style(tex) c(b(fmt(3) star) se(par fmt(3))) ///
	label collabels(, none) eqlabels(none) mlabels(, none) varlabel(_cons "constant" 1.disruptive "Disruptive" 1.disruptive#4.region "Disruptive $\times$ Africa"  1.disruptive#5.region "Disruptive $\times$ LAC") starlevel(* .1 ** .05 *** .01) ///
	keep(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	order(1.disruptive 1.disruptive#4.region 1.disruptive#5.region) ///
	stats(r2 N N_clust, fmt(%9.3f %9.0g) labels(`"$ R ^{2}$"' "Observations" "Countries")) replace 

	
	
***************************************************************** FIGURES *********************************************************************
***********************************************************************************************************************************************

********** Figure B2 **********
* setting the frontier
graph bar (mean) disruptive disruptive_nm if overlap == 0, over(region, relabel(1 `" "Frontier" "(Seattle" "London" "Tokyo" "Palo Alto)" "' 2 `" "Top 1000" "CB Ranking" "' 3 `" "Top 1000" "Revenue" "' 4 `" "Africa" "' 5 "LAC") label(labsize(vsmall))) ytitle(Pr. of being disruptive, size(small)) ylabel(,labsize(small)) title(Panel a. Extensive, size(small)) legend(order(1 "Disruptive" 2 "Disruptive-no mobile" ) size(small) region(lwidth(none)))
graph save one.gph, replace

graph bar (mean) technologies technologies_nm if overlap == 0 & disruptive == 1, over(region, relabel(1 `" "Frontier" "(Seattle" "London" "Tokyo" "Palo Alto)" "' 2 `" "Top 1000" "CB Ranking" "' 3 `" "Top 1000" "Revenue" "' 4 `" "Africa" "' 5 "LAC") label(labsize(vsmall))) ytitle(N of Disr. Technologies, size(small)) ylabel(,labsize(small)) title(Panel b. Intensive, size(small)) legend(order(1 "Disruptive" 2 "Disruptive-no mobile" ) size(small) region(lwidth(none)))
graph save two.gph, replace

graph combine one.gph two.gph
graph export "$figures/Figure_B2_frontier.png", replace


********** Figure 3
cap drop technologies_region_sector
* all
local controls lsimilar lage overlap i.labor

reg disruptive i.region `controls'
est store one

reg disruptive i.region `controls' if sector == 1
est store two

reg disruptive i.region `controls' if sector == 2
est store three

reg disruptive i.region `controls' if sector == 3
est store four

coefplot one two three four , keep(4.region 5.region) xline(0, lwidth(thick) lpatter(dash) lcolor(red)) ylabel(,labsize(small)) xlabel(-.14(0.02).14, labsize(vsmall)) legend(size(small) region(lwidth(none)) cols(4) order(2 "Overall" 4 "E-Commerce" 6 "Fintech" 8 "IT")) title(Panel a. Extensive Margin, size(small)) 
graph save extensive.gph, replace

reg technologies i.region `controls' if disruptive == 1
est store one

reg technologies i.region `controls' if sector == 1 & disruptive == 1
est store two

reg technologies i.region `controls' if sector == 2 & disruptive == 1
est store three

reg technologies i.region `controls' if sector == 3 & disruptive == 1
est store four

coefplot one two three four , keep(4.region 5.region) xline(0, lwidth(thick) lpatter(dash) lcolor(red)) ylabel(,labsize(small)) xlabel(-.14(0.02).14, labsize(vsmall)) legend(size(small) region(lwidth(none)) cols(4) order(2 "Overall" 4 "E-Commerce" 6 "Fintech" 8 "IT")) title(Panel b. Intensive Margin, size(small)) 
graph save intensive.gph, replace

graph combine extensive.gph intensive.gph
graph export "$figures/Figure_3a_frontier_split.png", replace

erase extensive.gph
erase intensive.gph

* non-mobile
local controls lsimilar lage overlap i.labor

reg disruptive_nm i.region `controls'
est store one

reg disruptive_nm i.region `controls' if sector == 1
est store two

reg disruptive_nm i.region `controls' if sector == 2
est store three

reg disruptive_nm i.region `controls' if sector == 3
est store four

coefplot one two three four , keep(4.region 5.region) xline(0, lwidth(thick) lpatter(dash) lcolor(red)) ylabel(,labsize(small)) xlabel(-.14(0.02).14, labsize(vsmall)) legend(size(small) region(lwidth(none)) cols(4) order(2 "Overall" 4 "E-Commerce" 6 "Fintech" 8 "IT")) title(Panel a. Extensive Margin, size(small)) 
graph save extensive.gph, replace

reg technologies_nm i.region `controls' if disruptive == 1
est store one

reg technologies_nm i.region `controls' if sector == 1 & disruptive == 1
est store two

reg technologies_nm i.region `controls' if sector == 2 & disruptive == 1
est store three

reg technologies_nm i.region `controls' if sector == 3 & disruptive == 1
est store four

coefplot one two three four , keep(4.region 5.region) xline(0, lwidth(thick) lpatter(dash) lcolor(red)) ylabel(,labsize(small)) xlabel(-.45(0.05).15, labsize(vsmall)) legend(size(small) region(lwidth(none)) cols(4) order(2 "Overall" 4 "E-Commerce" 6 "Fintech" 8 "IT")) title(Panel b. Intensive Margin, size(small)) 
graph save intensive.gph, replace

graph combine extensive.gph intensive.gph
graph export "$figures/Figure_3b_frontiernm_split.png", replace

erase extensive.gph
erase intensive.gph


********** Figure 4 **********
cap drop technologies_region_sector
** all
gen _labor = labor
sum _labor
local this = r(mean)
poisson technologies c.lage##i.region i._labor
replace _labor = `this'
predict technologies_region_labor, n
drop _labor

two ///
(line technologies_region_labor age if age <= 30 & region == 1, sort lpattern(dash) lwidth(thick)) ///
(line technologies_region_labor age if age <= 30 & region == 4, sort lwidth(thick) lcolor(blue)) ///
(line technologies_region_labor age if age <= 30 & region == 5, sort lwidth(thick) lcolor(magenta)) ///
, legend(size(small) cols(4) region(lwidth(none)) order(1 "Frontier" 2 "Africa" 3 "LAC"))  xtitle(Age in Years, size(small)) ytitle(N of Disr. Technologies, size(small)) xlabel(0(5)30,labsize(vsmall)) 
graph export "$figures/Figure_4a_age_region_labor.png", replace
drop technologies_region_labor

** excluding non-mobile
gen _labor = labor
sum _labor
local this = r(mean)
poisson technologies_nm c.lage##i.region i._labor
replace _labor = `this'
predict technologies_region_labor, n
drop _labor

two ///
(line technologies_region_labor age if age <= 30 & region == 1, sort lpattern(dash) lwidth(thick)) ///
(line technologies_region_labor age if age <= 30 & region == 4, sort lwidth(thick) lcolor(blue)) ///
(line technologies_region_labor age if age <= 30 & region == 5, sort lwidth(thick) lcolor(magenta)) ///
, legend(size(small) cols(4) region(lwidth(none)) order(1 "Frontier" 2 "Africa" 3 "LAC"))  xtitle(Age in Years, size(small)) ytitle(N of Disr. Technologies, size(small)) xlabel(0(5)30,labsize(vsmall)) 
graph export "$figures/Figure_4b_age_region_labor_nm.png", replace

********** Figure 5 **********
cap drop technologies_region_sector
** all
gen _labor = labor
reg technologies (c.lage##i.region)##i.sector i._labor
replace _labor = 0
predict technologies_region_sector, xb
drop _labor

two ///
(line technologies_region_sector age if age <= 30 & region == 1 & sector == 1, sort lpattern(dash) lwidth(thick)) ///
(line technologies_region_sector age if age <= 30 & region == 4 & sector == 1, sort lwidth(thick) lcolor(blue)) ///
(line technologies_region_sector age if age <= 30 & region == 5 & sector == 1, sort lwidth(thick) lcolor(magenta)) ///
, legend(size(vsmall) cols(4) region(lwidth(none)) order(1 "Frontier" 2 "Africa" 3 "LAC")) ylabel(0.2(0.1)0.7,labsize(vsmall)) xtitle(Age in Years, size(small)) ytitle(N of Disr. Technologies, size(small)) xlabel(0(5)30,labsize(vsmall)) title(E-Commerce, size(small)) yscale(range(0.2 0.7))
graph save one.gph, replace

two ///
(line technologies_region_sector age if age <= 30 & region == 1 & sector == 2, sort lpattern(dash) lwidth(thick)) ///
(line technologies_region_sector age if age <= 30 & region == 4 & sector == 2, sort lwidth(thick) lcolor(blue)) ///
(line technologies_region_sector age if age <= 30 & region == 5 & sector == 2, sort lwidth(thick) lcolor(magenta)) ///
, legend(size(vsmall) cols(4) region(lwidth(none)) order(1 "Frontier" 2 "Africa" 3 "LAC")) ylabel(0.2(0.1)0.7,labsize(vsmall)) xtitle(Age in Years, size(small)) ytitle(, size(zero)) xlabel(0(5)30,labsize(vsmall)) title(Fintech, size(small)) yscale(range(0.1 0.7))
graph save two.gph, replace

two ///
(line technologies_region_sector age if age <= 30 & region == 1 & sector == 3, sort lpattern(dash) lwidth(thick)) ///
(line technologies_region_sector age if age <= 30 & region == 4 & sector == 3, sort lwidth(thick) lcolor(blue)) ///
(line technologies_region_sector age if age <= 30 & region == 5 & sector == 3, sort lwidth(thick) lcolor(magenta)) ///
, legend(size(vsmall) cols(4) region(lwidth(none)) order(1 "Frontier" 2 "Africa" 3 "LAC")) ylabel(0.2(0.1)0.7,labsize(vsmall)) xtitle(Age in Years, size(small)) ytitle(, size(zero)) xlabel(0(5)30,labsize(vsmall)) title(IT, size(small)) yscale(range(0.2 0.7))
graph save three.gph, replace

graph combine one.gph two.gph three.gph, cols(3)
graph export "$figures/Figure_5a_age_region_sector.png", replace
drop technologies_region_sector 

** excluding non-mobile
gen _labor = labor
reg technologies_nm (c.lage##i.region)##i.sector i._labor
replace _labor = 0
predict technologies_region_sector, xb
drop _labor

two ///
(line technologies_region_sector age if age <= 30 & region == 1 & sector == 1, sort lpattern(dash) lwidth(thick)) ///
(line technologies_region_sector age if age <= 30 & region == 4 & sector == 1, sort lwidth(thick) lcolor(blue)) ///
(line technologies_region_sector age if age <= 30 & region == 5 & sector == 1, sort lwidth(thick) lcolor(magenta)) ///
, legend(size(vsmall) cols(4) region(lwidth(none)) order(1 "Frontier" 2 "Africa" 3 "LAC")) ylabel(0.2(0.1)0.7,labsize(vsmall)) xtitle(Age in Years, size(small)) ytitle(N of Disr. Technologies, size(small)) xlabel(0(5)30,labsize(vsmall)) title(E-Commerce, size(small)) yscale(range(0.2 0.7))
graph save one.gph, replace

two ///
(line technologies_region_sector age if age <= 30 & region == 1 & sector == 2, sort lpattern(dash) lwidth(thick)) ///
(line technologies_region_sector age if age <= 30 & region == 4 & sector == 2, sort lwidth(thick) lcolor(blue)) ///
(line technologies_region_sector age if age <= 30 & region == 5 & sector == 2, sort lwidth(thick) lcolor(magenta)) ///
, legend(size(vsmall) cols(4) region(lwidth(none)) order(1 "Frontier" 2 "Africa" 3 "LAC")) ylabel(0.2(0.1)0.7,labsize(vsmall)) xtitle(Age in Years, size(small)) ytitle(, size(zero)) xlabel(0(5)30,labsize(vsmall)) title(Fintech, size(small)) yscale(range(0.1 0.7))
graph save two.gph, replace

two ///
(line technologies_region_sector age if age <= 30 & region == 1 & sector == 3, sort lpattern(dash) lwidth(thick)) ///
(line technologies_region_sector age if age <= 30 & region == 4 & sector == 3, sort lwidth(thick) lcolor(blue)) ///
(line technologies_region_sector age if age <= 30 & region == 5 & sector == 3, sort lwidth(thick) lcolor(magenta)) ///
, legend(size(vsmall) cols(4) region(lwidth(none)) order(1 "Frontier" 2 "Africa" 3 "LAC")) ylabel(0.2(0.1)0.7,labsize(vsmall)) xtitle(Age in Years, size(small)) ytitle(, size(zero)) xlabel(0(5)30,labsize(vsmall)) title(IT, size(small)) yscale(range(0.2 0.7))
graph save three.gph, replace

graph combine one.gph two.gph three.gph, cols(3)
graph export "$figures/Figure_5b_age_region_sector_nm.png", replace

erase one.gph
erase two.gph
erase three.gph


********** Figure 6 **********
cap drop technologies_region_sector
** by country
*keep if overlap == 0
gen africa = .
replace africa = 0 if country == "South Africa"
replace africa = 1 if country == "Nigeria"
replace africa = 2 if country == "Egypt"
replace africa = 3 if country == "Kenya"
replace africa = 4 if africa == . & region == 4


gen lac = .
replace lac = 0 if country == "Brazil"
replace lac = 1 if country == "Mexico"
replace lac = 2 if country == "Argentina"
replace lac = 3 if country == "Colombia"
replace lac = 4 if lac == . & region == 5

gen _labor = labor
reg technologies (c.lage##i.region)##i.sector i._labor
replace _labor = 0
predict technologies_region_sector, xb
drop _labor

gen _labor = labor
reg technologies (c.lage##i.africa)##i.sector i._labor if region == 4
replace _labor = 0
predict technologies_africa, xb
drop _labor

gen _labor = labor
reg technologies (c.lage##i.lac)##i.sector i._labor if region == 5
replace _labor = 0
predict technologies_lac, xb
drop _labor

*--------------------- africa
two ///
(line technologies_region_sector age if age <= 30 & region == 4 & sector == 1, sort lcolor("255 0 0") lwidth(vvthick)) ///
(line technologies_africa age if age <= 30 & africa == 0 & sector == 1, sort lcolor("0 0 50") lwidth(vthick)) ///
(line technologies_africa age if age <= 30 & africa == 1 & sector == 1, sort lcolor("0 0 100") lwidth(thick)) ///
(line technologies_africa age if age <= 30 & africa == 2 & sector == 1, sort lcolor("0 0 150") lwidth(medthick)) ///
(line technologies_africa age if age <= 30 & africa == 3 & sector == 1, sort lcolor("0 0 150") lwidth(medthick) lpattern(longdash)) ///
(line technologies_africa age if age <= 30 & africa == 4 & sector == 1, sort lcolor("0 0 150") lwidth(medthick) lpattern(vshortdash)) ///
, legend(order(1 "All" 2 "ZAF" 3 "NIG" 4 "EGY" 5 "KEN" 6 "Rest") cols(3) size(vsmall) region(lwidth(none))) xtitle(Age in Years, size(vsmall)) xlabel(0(5)30,labsize(vsmall)) ytitle(N of Disr. Technologies,size(vsmall)) ylabel(0.2(0.1)0.5,labsize(vsmall)) yscale(range(0.1 0.5)) title(E-Commerce,size(small))
graph save one.gph, replace

two ///
(line technologies_region_sector age if age <= 30 & region == 4 & sector == 2, sort lcolor("255 0 0") lwidth(vvthick)) ///
(line technologies_africa age if age <= 30 & africa == 0 & sector == 2, sort lcolor("0 0 50") lwidth(vthick)) ///
(line technologies_africa age if age <= 30 & africa == 1 & sector == 2, sort lcolor("0 0 100") lwidth(thick)) ///
(line technologies_africa age if age <= 30 & africa == 2 & sector == 2, sort lcolor("0 0 150") lwidth(medthick)) ///
(line technologies_africa age if age <= 30 & africa == 3 & sector == 2, sort lcolor("0 0 150") lwidth(medthick) lpattern(longdash)) ///
(line technologies_africa age if age <= 30 & africa == 4 & sector == 2, sort lcolor("0 0 150") lwidth(medthick) lpattern(vshortdash)) ///
, legend(order(1 "All" 2 "ZAF" 3 "NIG" 4 "EGY" 5 "KEN" 6 "Rest") cols(3) size(vsmall) region(lwidth(none))) xtitle(Age in Years, size(vsmall)) xlabel(0(5)30,labsize(vsmall)) ytitle(,size(zero)) ylabel(0.2(0.1)0.5,labsize(vsmall)) yscale(range(0.1 0.5)) title(Fintech,size(small))
graph save two.gph, replace

two ///
(line technologies_region_sector age if age <= 30 & region == 4 & sector == 3, sort lcolor("255 0 0") lwidth(vvthick)) ///
(line technologies_africa age if age <= 30 & africa == 0 & sector == 3, sort lcolor("0 0 50") lwidth(vthick)) ///
(line technologies_africa age if age <= 30 & africa == 1 & sector == 3, sort lcolor("0 0 100") lwidth(thick)) ///
(line technologies_africa age if age <= 30 & africa == 2 & sector == 3, sort lcolor("0 0 150") lwidth(medthick)) ///
(line technologies_africa age if age <= 30 & africa == 3 & sector == 3, sort lcolor("0 0 150") lwidth(medthick) lpattern(longdash)) ///
(line technologies_africa age if age <= 30 & africa == 4 & sector == 3, sort lcolor("0 0 150") lwidth(medthick) lpattern(vshortdash)) ///
, legend(order(1 "All" 2 "ZAF" 3 "NIG" 4 "EGY" 5 "KEN" 6 "Rest") cols(3) size(vsmall) region(lwidth(none))) xtitle(Age in Years, size(vsmall)) xlabel(0(5)30,labsize(vsmall)) ytitle(,size(zero)) ylabel(0.2(0.1)0.5,labsize(vsmall)) yscale(range(0.1 0.5)) title(IT,size(small))
graph save three.gph, replace

graph combine one.gph two.gph three.gph, cols(3)
graph export "$figures/Figure_6a_africa.png", replace
drop technologies_africa technologies_lac technologies_region_sector

******** excluding non-mobile
gen _labor = labor
reg technologies_nm (c.lage##i.region)##i.sector i._labor
replace _labor = 0
predict technologies_region_sector, xb
drop _labor

gen _labor = labor
reg technologies_nm (c.lage##i.africa)##i.sector i._labor if region == 4
replace _labor = 0
predict technologies_africa, xb
drop _labor

gen _labor = labor
reg technologies_nm (c.lage##i.lac)##i.sector i._labor if region == 5
replace _labor = 0
predict technologies_lac, xb
drop _labor

*--------------------- africa
two ///
(line technologies_region_sector age if age <= 30 & region == 4 & sector == 1, sort lcolor("255 0 0") lwidth(vvthick)) ///
(line technologies_africa age if age <= 30 & africa == 0 & sector == 1, sort lcolor("0 0 50") lwidth(vthick)) ///
(line technologies_africa age if age <= 30 & africa == 1 & sector == 1, sort lcolor("0 0 100") lwidth(thick)) ///
(line technologies_africa age if age <= 30 & africa == 2 & sector == 1, sort lcolor("0 0 150") lwidth(medthick)) ///
(line technologies_africa age if age <= 30 & africa == 3 & sector == 1, sort lcolor("0 0 150") lwidth(medthick) lpattern(longdash)) ///
(line technologies_africa age if age <= 30 & africa == 4 & sector == 1, sort lcolor("0 0 150") lwidth(medthick) lpattern(vshortdash)) ///
, legend(order(1 "All" 2 "ZAF" 3 "NIG" 4 "EGY" 5 "KEN" 6 "Rest") cols(3) size(vsmall) region(lwidth(none))) xtitle(Age in Years, size(vsmall)) xlabel(0(5)30,labsize(vsmall)) ytitle(N of Disr. Technologies,size(vsmall)) ylabel(0.2(0.1)0.5,labsize(vsmall)) yscale(range(0.1 0.5)) title(E-Commerce,size(small))
graph save one.gph, replace

two ///
(line technologies_region_sector age if age <= 30 & region == 4 & sector == 2, sort lcolor("255 0 0") lwidth(vvthick)) ///
(line technologies_africa age if age <= 30 & africa == 0 & sector == 2, sort lcolor("0 0 50") lwidth(vthick)) ///
(line technologies_africa age if age <= 30 & africa == 1 & sector == 2, sort lcolor("0 0 100") lwidth(thick)) ///
(line technologies_africa age if age <= 30 & africa == 2 & sector == 2, sort lcolor("0 0 150") lwidth(medthick)) ///
(line technologies_africa age if age <= 30 & africa == 3 & sector == 2, sort lcolor("0 0 150") lwidth(medthick) lpattern(longdash)) ///
(line technologies_africa age if age <= 30 & africa == 4 & sector == 2, sort lcolor("0 0 150") lwidth(medthick) lpattern(vshortdash)) ///
, legend(order(1 "All" 2 "ZAF" 3 "NIG" 4 "EGY" 5 "KEN" 6 "Rest") cols(3) size(vsmall) region(lwidth(none))) xtitle(Age in Years, size(vsmall)) xlabel(0(5)30,labsize(vsmall)) ytitle(,size(zero)) ylabel(0.2(0.1)0.5,labsize(vsmall)) yscale(range(0.1 0.5)) title(Fintech,size(small))
graph save two.gph, replace

two ///
(line technologies_region_sector age if age <= 30 & region == 4 & sector == 3, sort lcolor("255 0 0") lwidth(vvthick)) ///
(line technologies_africa age if age <= 30 & africa == 0 & sector == 3, sort lcolor("0 0 50") lwidth(vthick)) ///
(line technologies_africa age if age <= 30 & africa == 1 & sector == 3, sort lcolor("0 0 100") lwidth(thick)) ///
(line technologies_africa age if age <= 30 & africa == 2 & sector == 3, sort lcolor("0 0 150") lwidth(medthick)) ///
(line technologies_africa age if age <= 30 & africa == 3 & sector == 3, sort lcolor("0 0 150") lwidth(medthick) lpattern(longdash)) ///
(line technologies_africa age if age <= 30 & africa == 4 & sector == 3, sort lcolor("0 0 150") lwidth(medthick) lpattern(vshortdash)) ///
, legend(order(1 "All" 2 "ZAF" 3 "NIG" 4 "EGY" 5 "KEN" 6 "Rest") cols(3) size(vsmall) region(lwidth(none))) xtitle(Age in Years, size(vsmall)) xlabel(0(5)30,labsize(vsmall)) ytitle(,size(zero)) ylabel(0.2(0.1)0.5,labsize(vsmall)) yscale(range(0.1 0.5)) title(IT,size(small))
graph save three.gph, replace

graph combine one.gph two.gph three.gph, cols(3)
graph export "$figures/Figure_6b_africa_nm.png", replace
drop technologies_africa technologies_lac technologies_region_sector

erase one.gph
erase two.gph
erase three.gph
