clear 
set more off
set scheme s1color

** PATHS
/*
local working ../working
local figures ../figures
local tables ../tables
*/

** DATA
use "$working/roster", clear
merge 1:1 firm_id using "$working/roster_technology_list_wide"
drop _merge
recode tech_* (. = 0)

egen technologies = rowtotal(tech_*)
gen disruptive = technologies > 0
gen technologies_nm = technologies - (tech_7 + tech_14)
gen disruptive_nm = technologies_nm > 0

compress

replace age = age - 1
recode age (-1 = 0)

gen lage = ln(age + sqrt(age^2 + 1))
gen lsimilar = ln(similar + sqrt(similar^2 + 1))
gen lfunding = ln(funding_last + sqrt(funding_last^2 + 1))
gen lfundingt = ln(funding_total + sqrt(funding_total^2 + 1))
gen lequity = ln(v58 + sqrt(v58^2 + 1))

recode technologies (2/99 = 2), gen(technologies_censored)
gen technologies_dummy = technologies > 0

recode technologies_nm (2/99 = 2), gen(technologies_nm_censored)
gen technologies_nm_dummy = technologies_nm > 0

gen tech_rate = technologies / btechnologies

sort orgname country sector
by orgname country: gen unique = _n

gen closed_year = real(substr(closeddate,1,4))

keep if closed_year == .

gen dft = funding_total > 0
gen dfl = funding_last > 0

mat define X = J(15,7,.)
forvalues x = 1/15 {
	local controls lsimilar lage overlap i.labor 
	
	qui gen D = tech_`x'
	qui gen R = technologies - tech_`x'
	qui recode R (1/99 = 1)

	qui areg dft (i.D i.R)##i.region `controls' if inlist(region,1,4,5) & unique == 1, abs(country) vce(cluster country)
	estimates store t`x'
	mat define X[`x',1] = `x'
	mat define X[`x',2] = _b[1.D]
	mat define X[`x',5] = _se[1.D]

	qui lincom _b[1.D] + _b[1.D#4.region]
	mat define X[`x',3] = r(estimate)
	mat define X[`x',6] = r(se)
	
	qui lincom _b[1.D] + _b[1.D#5.region]
	mat define X[`x',4] = r(estimate)
	mat define X[`x',7] = r(se)
	
	qui drop  D R
}

clear
svmat X

#delimit ;
label define technology
1	"3d Printing"
2	"Cloud Computing"
3	"Computer Vision"
4	"Electronic Gaming"
5	"GPS"
6	"Machine Learning/AI"
7	"Mobile Payment"
8	"Online Streaming"
9	"Search Engine"
10	"Smart Devices"
11	"Social Networking"
12	"Solar Power"
13	"Virtual Reality"
14	"WiFi"
15	"Rest"
;

#delimit cr
gsort -X2
label values X1 technology
decode X1, gen(_rank)
gen rank = _n
replace rank = rank - 0.15
gen rank_africa = rank + 0.15
gen rank_lac = rank_africa + 0.15

labmask rank_africa, val(_rank)

rename X2 beta_frontier
rename X3 beta_africa
rename X4 beta_lac
rename X5 se_frontier
rename X6 se_africa
rename X7 se_lac
foreach i in frontier africa lac {
	gen hi_`i' = beta_`i' + 1.96*se_`i'
	gen lo_`i' = beta_`i' - 1.96*se_`i'
}

two ///
(rcap hi_africa lo_africa rank_africa, lcolor(orange) lwidth(vthin)) ///
(rcap hi_frontier lo_frontier rank, lcolor(green) lwidth(vthin)) ///
(rcap hi_lac lo_lac rank_lac, lcolor(navy) lwidth(vthin)) ///
(scatter beta_africa rank_africa, mcolor(orange) msize(vsmall)) ///
(scatter beta_frontier rank, mcolor(green) msize(vsmall)) ///
(scatter beta_lac rank_lac, mcolor(navy) msize(vsmall)) ///
, yline(0, lpattern(dash)) xlabel(1(1)15, valuelabel angle(90) labsize(vsmall)) xtitle(,size(zero)) ///
legend(order(5 "Frontier" 4 "Africa" 6 "LAC") cols(3) size(small) region(lwidth(none))) ylabel(,labsize(small))

graph export "$figures/Figure B4_results_hetero.png", replace
