clear 
set more off
set scheme s1color

** PATHS
/*
local working ../working
local figures ../figures
local tables ../tables
*/
** DATA
use "$working/roster", clear
merge 1:1 firm_id using "$working/roster_technology_list_wide2005"
drop _merge
recode tech_* (. = 0)

replace country = "United States" if country == "Palo Alto" | country == "Seattle"
replace country = "United Kingdom" if country == "London"
replace country = "Japan" if country == "Tokyo"

qui include "$dofiles\01_dataprep\iso_code.do"

egen technologies = rowtotal(tech_*)
gen disruptive = technologies > 0
gen technologies_nm = technologies - (tech_6)
gen disruptive_nm = technologies_nm > 0

compress
merge m:1 iso_code using "$working/mismatch_normative"
drop if _merge == 2
drop _merge

gen year = year_start
merge m:1 iso_code year using "$data/other/wdi"
drop if _merge == 2
drop _merge

merge m:1 iso_code year using "$data/other/predicted"
drop if _merge == 2
drop _merge

split industries, gen(ind_) parse(",")

forvalues x = 1/29 {
	replace ind_`x' = trim(ind_`x')
	gen ind_ = ind_`x'
	merge m:1 ind_ using "$working/shareF"
	drop if _merge == 2
	rename shareD shareD_`x'
	rename shareDnm shareDnm_`x'
	drop ind_ _merge
}

egen shareD = rowmean(shareD_*)
egen shareDnm = rowmean(shareDnm_*)

drop shareD_* shareDnm_* ind_*

replace age = age - 1
recode age (-1 = 0)

gen lage = ln(age + sqrt(age^2 + 1))
gen lsimilar = ln(similar + sqrt(similar^2 + 1))
gen lfundingl = ln(funding_last + sqrt(funding_last^2 + 1))
gen lfundingt = ln(funding_total + sqrt(funding_total^2 + 1))
gen lequity = ln(v58 + sqrt(v58^2 + 1))

gen lpop = ln(pop1564)
gen lgdppc = ln(gdp2015)
gen lM = ln((M_formal_small + M_formal_medium + M_formal_large))

recode technologies (2/99 = 2), gen(technologies_censored)
gen technologies_dummy = technologies > 0

recode technologies_nm (2/99 = 2), gen(technologies_nm_censored)
gen technologies_nm_dummy = technologies_nm > 0

gen tech_rate = technologies / btechnologies

sort orgname country sector
by orgname country: gen unique = _n

gen closed_year = real(substr(closeddate,1,4))

keep if closed_year == .

gen dft = funding_total > 0
gen dfl = funding_last > 0

egen technology_year = rowmin(techy_*)
recode technology_year (. = 0)

keep if year >= 2010

egen i = group(iso_code)

keep if region == 5

************************************************************************** table A6: funding_extensiveIV_lac.tex
*inputs: _funding_extensiveIV_lac.tex, _funding_extensiveIHSIV_lac.tex and _funding_intensiveIHSIV_lac.tex

******************************** extensive
local controls lsimilar lage overlap i.labor lpop lgdppc i.sector lM

gen iv_f = (match_total + over_total) * shareD   
gen iv_d = (match_total + over_total) * shareD    
gen iv_dnm = (match_total + over_total) * shareDnm  


ivregress 2sls dft (disruptive = iv_d) `controls' if unique == 1, vce(cluster iso_code)
est store dft

ivregress 2sls dfl (disruptive = iv_d) `controls' if unique == 1, vce(cluster iso_code)
est store dfl

rename disruptive _dd
rename disruptive_nm disruptive
ivregress 2sls dft (disruptive = iv_dnm) `controls' if unique == 1, vce(cluster iso_code)
est store dftnm

ivregress 2sls dfl (disruptive = iv_dnm) `controls' if unique == 1, vce(cluster iso_code)
est store dflnm

rename disruptive disruptive_nm
rename _dd disruptive

noisily estout dft dfl dftnm dflnm using "$tables/TableA6a_funding_extensiveIV_lac.tex", style(tex) c(b(fmt(3) star) se(par fmt(3))) ///
	label collabels(, none) eqlabels(none) mlabels(, none) varlabel(_cons "constant" disruptive "Disruptive") starlevel(* .1 ** .05 *** .01) ///
	keep(disruptive) ///
	order(disruptive) ///
	stats(r2 N N_clust, fmt(%9.3f %9.0g) labels(`"$ R ^{2}$"' "Observations" "Countries")) replace 

******************************** extensive + intensive
ivregress 2sls lfundingt (disruptive = iv_d) `controls' if unique == 1, vce(cluster iso_code)
est store dft

ivregress 2sls lfundingl (disruptive = iv_d) `controls' if unique == 1, vce(cluster iso_code)
est store dfl

rename disruptive _dd
rename disruptive_nm disruptive
ivregress 2sls lfundingt (disruptive = iv_dnm) `controls' if unique == 1, vce(cluster iso_code)
est store dftnm

ivregress 2sls lfundingl (disruptive = iv_dnm) `controls' if unique == 1, vce(cluster iso_code)
est store dflnm

rename disruptive disruptive_nm
rename _dd disruptive

noisily estout dft dfl dftnm dflnm using "$tables/TableA6b_funding_extensiveIHSIV_lac.tex", style(tex) c(b(fmt(3) star) se(par fmt(3))) ///
	label collabels(, none) eqlabels(none) mlabels(, none) varlabel(_cons "constant" disruptive "Disruptive") starlevel(* .1 ** .05 *** .01) ///
	keep(disruptive) ///
	order(disruptive) ///
	stats(r2 N N_clust, fmt(%9.3f %9.0g) labels(`"$ R ^{2}$"' "Observations" "Countries")) replace 

******************************** intensive
ivregress 2sls lfundingt (disruptive = iv_d) `controls' if unique == 1 & dft == 1, vce(cluster iso_code)
est store dft

ivregress 2sls lfundingl (disruptive = iv_d) `controls' if unique == 1 & dfl == 1, vce(cluster iso_code)
est store dfl

rename disruptive _dd
rename disruptive_nm disruptive
ivregress 2sls lfundingt (disruptive = iv_dnm) `controls' if unique == 1 & dft == 1, vce(cluster iso_code)
est store dftnm

ivregress 2sls lfundingl (disruptive = iv_dnm) `controls' if unique == 1 & dfl == 1, vce(cluster iso_code)
est store dflnm

rename disruptive disruptive_nm
rename _dd disruptive

noisily estout dft dfl dftnm dflnm using "$tables/TableA6c_funding_intensiveIHSIV_lac.tex", style(tex) c(b(fmt(3) star) se(par fmt(3))) ///
	label collabels(, none) eqlabels(none) mlabels(, none) varlabel(_cons "constant" disruptive "Disruptive") starlevel(* .1 ** .05 *** .01) ///
	keep(disruptive) ///
	order(disruptive) ///
	stats(r2 N N_clust, fmt(%9.3f %9.0g) labels(`"$ R ^{2}$"' "Observations" "Countries")) replace 

************************************************************************** table A7: funding_extensiveIVi_lac.tex
*inputs: _funding_extensiveIVi_lac.tex, _funding_extensiveIHSIVi_lac.tex and _funding_intensiveIHSIVi_lac.tex

**** IV + country FE
******************************** extensive
local controls lsimilar lage overlap i.labor lpop lgdppc i.sector lM i.i

ivregress 2sls dft (disruptive = iv_d) `controls' if unique == 1, vce(cluster iso_code)
est store dft

ivregress 2sls dfl (disruptive = iv_d) `controls' if unique == 1, vce(cluster iso_code)
est store dfl

rename disruptive _dd
rename disruptive_nm disruptive
ivregress 2sls dft (disruptive = iv_dnm) `controls' if unique == 1, vce(cluster iso_code)
est store dftnm

ivregress 2sls dfl (disruptive = iv_dnm) `controls' if unique == 1, vce(cluster iso_code)
est store dflnm

rename disruptive disruptive_nm
rename _dd disruptive

noisily estout dft dfl dftnm dflnm using "$tables/TableA7a_funding_extensiveIVi_lac.tex", style(tex) c(b(fmt(3) star) se(par fmt(3))) ///
	label collabels(, none) eqlabels(none) mlabels(, none) varlabel(_cons "constant" disruptive "Disruptive") starlevel(* .1 ** .05 *** .01) ///
	keep(disruptive) ///
	order(disruptive) ///
	stats(r2 N N_clust, fmt(%9.3f %9.0g) labels(`"$ R ^{2}$"' "Observations" "Countries")) replace 

******************************** extensive + intensive
ivregress 2sls lfundingt (disruptive = iv_d) `controls' if unique == 1, vce(cluster iso_code)
est store dft

ivregress 2sls lfundingl (disruptive = iv_d) `controls' if unique == 1, vce(cluster iso_code)
est store dfl

rename disruptive _dd
rename disruptive_nm disruptive
ivregress 2sls lfundingt (disruptive = iv_dnm) `controls' if unique == 1, vce(cluster iso_code)
est store dftnm

ivregress 2sls lfundingl (disruptive = iv_dnm) `controls' if unique == 1, vce(cluster iso_code)
est store dflnm

rename disruptive disruptive_nm
rename _dd disruptive

noisily estout dft dfl dftnm dflnm using "$tables/TableA7b_funding_extensiveIHSIVi_lac.tex", style(tex) c(b(fmt(3) star) se(par fmt(3))) ///
	label collabels(, none) eqlabels(none) mlabels(, none) varlabel(_cons "constant" disruptive "Disruptive") starlevel(* .1 ** .05 *** .01) ///
	keep(disruptive) ///
	order(disruptive) ///
	stats(r2 N N_clust, fmt(%9.3f %9.0g) labels(`"$ R ^{2}$"' "Observations" "Countries")) replace 

******************************** intensive
ivregress 2sls lfundingt (disruptive = iv_d) `controls' if unique == 1 & dft == 1, vce(cluster iso_code)
est store dft

ivregress 2sls lfundingl (disruptive = iv_d) `controls' if unique == 1 & dfl == 1, vce(cluster iso_code)
est store dfl

rename disruptive _dd
rename disruptive_nm disruptive
ivregress 2sls lfundingt (disruptive = iv_dnm) `controls' if unique == 1 & dft == 1, vce(cluster iso_code)
est store dftnm

ivregress 2sls lfundingl (disruptive = iv_dnm) `controls' if unique == 1 & dfl == 1, vce(cluster iso_code)
est store dflnm

rename disruptive disruptive_nm
rename _dd disruptive

noisily estout dft dfl dftnm dflnm using "$tables/TableA7c_funding_intensiveIHSIVi_lac.tex", style(tex) c(b(fmt(3) star) se(par fmt(3))) ///
	label collabels(, none) eqlabels(none) mlabels(, none) varlabel(_cons "constant" disruptive "Disruptive") starlevel(* .1 ** .05 *** .01) ///
	keep(disruptive) ///
	order(disruptive) ///
	stats(r2 N N_clust, fmt(%9.3f %9.0g) labels(`"$ R ^{2}$"' "Observations" "Countries")) replace 



******************************** first stage: not reported
/*



reg disruptive iv_d `controls', // vce(cluster i)
est store iv_d

reg disruptive_nm iv_dnm `controls', // vce(cluster i)
est store iv_dnm

areg disruptive iv_d `controls', abs(i) // vce(cluster i)
est store iv_di

areg disruptive_nm iv_dnm `controls', abs(i) // vce(cluster i)
est store iv_dnmi

noisily estout iv_d iv_di iv_dnm iv_dnmi using "$tables/_firststage_lac.tex", style(tex) c(b(fmt(3) star) se(par fmt(3))) ///
	label collabels(, none) eqlabels(none) mlabels(, none) varlabel(_cons "constant" iv_d "IV" iv_dnm "IV-non mobile") starlevel(* .1 ** .05 *** .01) ///
	keep(iv_d iv_dnm) ///
	order(iv_d iv_dnm) ///
	stats(r2 N F, fmt(%9.3f %9.0g %9.2f) labels(`"$ R ^{2}$"' "Observations" "F-Value")) replace 
	/*
