clear 
set more off
set scheme s1color

*/* PATHS
local working ../working
local figures ../figures
local tables ../tables
*/
** DATA
use "$working/rosterp", clear
merge 1:1 companyid using "$working/rosterp_technology_list_wide"
drop _merge
recode tech_* (. = 0)

egen technologies = rowtotal(tech_*)
gen disruptive = technologies > 0
gen technologies_nm = technologies - (tech_7 + tech_14)
gen disruptive_nm = technologies_nm > 0

egen technology_year = rowmin(techy_*) if disruptive_nm == 1
replace technology_year = 0 if disruptive_nm == 0

** cleaning
drop if firstfinancingdealtype == ""
drop if regexm(firstfinancingdealtype,"Merge")
drop if regexm(firstfinancingdealtype,"Joint")


**
gen deal_type_first = .
replace deal_type_first = 0 if firstfinancingdealtype == "Angel (individual)"
replace deal_type_first = 0 if firstfinancingdealtype == "Grant"
replace deal_type_first = 1 if firstfinancingdealtype == "Accelerator/Incubator"
replace deal_type_first = 2 if firstfinancingdealtype == "Seed Round"
replace deal_type_first = 3 if firstfinancingdealtype == "Early Stage VC"
replace deal_type_first = 4 if firstfinancingdealtype == "Later Stage VC"
replace deal_type_first = 5 if firstfinancingdealtype == "Mezzanine"
replace deal_type_first = 5 if firstfinancingdealtype == "PE Growth/Expansion"
replace deal_type_first = 6 if firstfinancingdealtype == "Buyout/LBO"
replace deal_type_first = 6 if firstfinancingdealtype == "IPO"

replace deal_type_first = 2 if firstfinancingdealtype2 == "Series 1"
replace deal_type_first = 3 if firstfinancingdealtype2 == "Series 2"
replace deal_type_first = 3 if firstfinancingdealtype2 == "Series A"
replace deal_type_first = 4 if firstfinancingdealtype2 == "Series A1"
replace deal_type_first = 4 if firstfinancingdealtype2 == "Series A2"
replace deal_type_first = 4 if firstfinancingdealtype2 == "Series B"

gen deal_type_last = .
replace deal_type_last = 0 if lastfinancingdealtype == "Angel (individual)"
replace deal_type_last = 0 if lastfinancingdealtype == "Grant"
replace deal_type_last = 1 if lastfinancingdealtype == "Accelerator/Incubator"
replace deal_type_last = 2 if lastfinancingdealtype == "Seed Round"
replace deal_type_last = 3 if lastfinancingdealtype == "Early Stage VC"
replace deal_type_last = 4 if lastfinancingdealtype == "Later Stage VC"
replace deal_type_last = 5 if lastfinancingdealtype == "Mezzanine"
replace deal_type_last = 5 if lastfinancingdealtype == "PE Growth/Expansion"
replace deal_type_last = 6 if lastfinancingdealtype == "Buyout/LBO"
replace deal_type_last = 6 if lastfinancingdealtype == "IPO"

replace deal_type_last = 2 if lastfinancingdealtype2 == "Series 1"
replace deal_type_last = 3 if lastfinancingdealtype2 == "Series 2"
replace deal_type_last = 3 if lastfinancingdealtype2 == "Series A"
replace deal_type_last = 4 if lastfinancingdealtype2 == "Series A1"
replace deal_type_last = 4 if lastfinancingdealtype2 == "Series A2"
replace deal_type_last = 4 if lastfinancingdealtype2 == "Series B"

recode deal_type_first deal_type_last (4 5 6 = 4)

destring opportunityscore successprobability, replace ignore("%")
recode successprobability (. = 0)

gen _first_year = substr( firstfinancingdate,-2,2)
gen first_year = 2000 + real(_first_year) if real(_first_year) >= 0 & real(_first_year) <= 23
replace first_year = 1900 + real(_first_year) if real(_first_year) > 23

gen _last_year = substr( lastknownvaluationdate,-2,2)
gen last_year = 2000 + real(_last_year) if real(_last_year) >= 0 & real(_last_year) <= 23
replace last_year = 1900 + real(_last_year) if real(_last_year) > 23


* similar
split competitors, gen(compet_) parse(",")
local cnumber = r(nvars)

forvalues x = 1/`cnumber' {
	gen cc_`x' = compet_`x' != ""
}

egen similar = rowtotal(cc_*)

drop compet_* cc_*

* sectors
encode primaryindustrysector, gen(sector)

gen age = 2023 - real(yearfounded)

destring firstfinancingsize, gen(funding_first) ignore(",")
destring lastfinancingsize, gen(funding_last) ignore(",")
destring employees, replace ignore(",")
destring firstfinancingvaluation, gen(valuation_first) ignore(",")
destring lastknownvaluation, gen(valuation_last) ignore(",")
destring revenue, replace ignore(",")


recode funding* employees valuation* (. = 0)

foreach var in funding_first funding_last age similar employees valuation_first{
	gen l`var' = ln(`var' + sqrt(`var'^2 + 1))	
}

gen dff = funding_first > 0
gen dfl = funding_last > 0

gen rpw = revenue / employees

gen ever = funding_first > 0
replace ever = 1 if funding_last > 0

gen first_duration = first_year - real(yearfounded)
gen valuation_growth = ln(valuation_last/valuation_first)
gen valuation_growth_annual = (1+valuation_growth)^(1/(last_year - first_year + 1))

gen ticket_growth = ln(funding_last/funding_first)
gen ticket_growth_annual = (1+ticket_growth)^(1/(last_year - first_year + 1))


gen deal_growth = deal_type_last - deal_type_first
recode deal_growth (-9/0 = 0) (1/9 = 1)

** performance
local controls lage lsimilar lemployees i.sector
local ys first_duration lfunding_first lvaluation_first successprobability valuation_growth valuation_growth_annual deal_growth

local c = 1
foreach y in `ys' {
	areg `y' 1.disruptive_nm##i.region `controls' if ever == 1 & inlist(region,4,5), abs(country) vce(cluster country)
	estimates store r`c'
	local ++c
}
/*
noisily estout r* using "$tables/_pitch.tex", style(tex) c(b(fmt(3) star) se(par fmt(3))) ///
	label collabels(, none) eqlabels(none) mlabels(, none) varlabel(_cons "constant" 1.disruptive_nm "Disruptive"  1.disruptive_nm#5.region "Disruptive $\times$ LAC") starlevel(* .1 ** .05 *** .01) ///
	keep(1.disruptive_nm 1.disruptive_nm#5.region) ///
	order(1.disruptive_nm 1.disruptive_nm#5.region) ///
	stats(r2 N N_clust, fmt(%9.3f %9.0g) labels(`"$ R ^{2}$"' "Observations" "Countries")) replace 
*/

***************************************************************** Table 5: funding_pitch.tex
* inputs: _pitch_f.rex and _pitch_a.tex	
	
** performance pre
gen flag = technology_year >= first_year
local controls lage lsimilar lemployees i.sector
local ys first_duration lfunding_first lvaluation_first successprobability valuation_growth valuation_growth_annual deal_growth

local c = 1
foreach y in `ys' {
	areg `y' 1.disruptive_nm##i.region `controls' if ever == 1 & inlist(region,4,5) & flag == 0, abs(country) vce(cluster country)
	estimates store r`c'
	local ++c
}

noisily estout r* using "$tables/Table5a_pitch_f.tex", style(tex) c(b(fmt(3) star) se(par fmt(3))) ///
	label collabels(, none) eqlabels(none) mlabels(, none) varlabel(_cons "constant" 1.disruptive_nm "Disruptive"  1.disruptive_nm#5.region "Disruptive $\times$ LAC") starlevel(* .1 ** .05 *** .01) ///
	keep(1.disruptive_nm 1.disruptive_nm#5.region) ///
	order(1.disruptive_nm 1.disruptive_nm#5.region) ///
	stats(r2 N N_clust, fmt(%9.3f %9.0g) labels(`"$ R ^{2}$"' "Observations" "Countries")) replace 


** performance pre born before
gen flag_age = technology_year >= real(yearfounded)
local controls lage lsimilar lemployees i.sector
local ys first_duration lfunding_first lvaluation_first successprobability valuation_growth valuation_growth_annual deal_growth

local c = 1
foreach y in `ys' {
	areg `y' 1.disruptive_nm##i.region `controls' if ever == 1 & inlist(region,4,5) & flag == 0 & flag_age == 0, abs(country) vce(cluster country)
	estimates store r`c'
	local ++c
}

noisily estout r* using "$tables/Table5b_pitch_a.tex", style(tex) c(b(fmt(3) star) se(par fmt(3))) ///
	label collabels(, none) eqlabels(none) mlabels(, none) varlabel(_cons "constant" 1.disruptive_nm "Disruptive"  1.disruptive_nm#5.region "Disruptive $\times$ LAC") starlevel(* .1 ** .05 *** .01) ///
	keep(1.disruptive_nm 1.disruptive_nm#5.region) ///
	order(1.disruptive_nm 1.disruptive_nm#5.region) ///
	stats(r2 N N_clust, fmt(%9.3f %9.0g) labels(`"$ R ^{2}$"' "Observations" "Countries")) replace 	
